% Main for the experiment over 8 realizations of dem
% Intensity format and L=1 for simulated SAR images
% This demo shows results for kuan filter (5x5 window)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% Copyright (c) 2013 Image Processing Research Group of University Federico II of Naples ('GRIP-UNINA').
% All rights reserved.
% this software should be used, reproduced and modified only for informational and nonprofit purposes.
% 
% By downloading and/or using any of these files, you implicitly agree to all the
% terms of the license, as specified in the document LICENSE.txt
% (included in this package) and online at
% http://www.grip.unina.it/download/LICENSE_OPEN.txt
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all; close all; clc;
load dem_clean;
load dem_noisy;

for i=1:8,
    y(:,:,i) = kuan(z(:,:,i),1,2);
    [MoI(i), MoR(i), VoR(i), Cx(i), DG(i)] = dem_measures(x,y(:,:,i),z(:,:,i));
end

format compact;
disp(sprintf('MoI = %0.3g', mean(MoI)));
disp(sprintf('MoR = %0.3g', mean(MoR)));
disp(sprintf('VoR = %0.3g', mean(VoR)));
disp(sprintf('Cx  = %0.3g', mean(Cx)));
disp(sprintf('DG  = %0.3g', mean(DG)));

% display
figure(1); 
subplot(1,3,1); imshow(sqrt(x),[0 7]); title('clean');
subplot(1,3,2); imshow(sqrt(y(:,:,1)),[0 7]); title('filtered');
subplot(1,3,3); imshow(sqrt(z(:,:,1)),[0 7]); title('noisy');

figure(2); 
imshow(sqrt(z(:,:,1)./y(:,:,1)),[0 4]); 
title('ratio');

pause;

for i=1:8,
    C_filtered(:,:,i) = cov_mtx(y(:,:,i));
    C_noisy(:,:,i) = cov_mtx(z(:,:,i));
end
C_clean = cov_mtx(x);

figure(3); 
C_filtered = mean(C_filtered,3); plot([0:30],C_filtered(31:61,31),'r','LineWidth',2); hold on;
C_noisy = mean(C_noisy,3); plot([0:30],C_noisy(31:61,31),'k--','LineWidth',2);
plot([0:30],C_clean(31:61,31),'k','LineWidth',2); 
legend('Filtered','Noisy','Clean');
axis([0 30 0 10]);