function [MoI, MoR, VoR, C, DG] = dem_measures(x,y,z)
%dem_measures is the version 0.1 to evaluate 
% performance on Dem SAR simulated images as described in 
% "Benchmarking framework for SAR despeckling", written by
% G. Di Martino, M. Poderico, G. Poggi, D.Riccio and L. Verdoliva, 
% IEEE Trans. on Geoscience and Remote Sensing, in press, 2013.
% Please cite this paper when using these measures.
%
% DEM measures (Intensity format)
% [MoI, MoR, VoR, C, DG] = dem_measures(x,y,z)
% x: clean image, y: filtered image; z: noisy image (all intensity format)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% Copyright (c) 2013 Image Processing Research Group of University Federico II of Naples ('GRIP-UNINA').
% All rights reserved.
% this software should be used, reproduced and modified only for informational and nonprofit purposes.
% 
% By downloading and/or using any of these files, you implicitly agree to all the
% terms of the license, as specified in the document LICENSE.txt
% (included in this package) and online at
% http://www.grip.unina.it/download/LICENSE_OPEN.txt
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Mean of Image
MoI = mean2(y);

% ratio statistics
ratio = z./y;
MoR = mean2(ratio);
VoR = std2(ratio).^2;

% C
C = std2(y)/mean2(y);

% DG
mse1 = sum((x(:)-z(:)).^2);
mse2 = sum((x(:)-y(:)).^2);
DG = 10*log10(mse1/mse2);